@@ -2,11 +2,11 @@
  *  html.c
  *  mod_musicindex
  *
- *  $Id: html.c 768 2007-08-22 12:35:16Z varenet $
+ *  $Id: html.c 780 2008-03-30 17:34:13Z varenet $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2006 Regis BOUDIN
- *  Copyright (c) 2003-2007 Thibaut VARENE
+ *  Copyright (c) 2003-2008 Thibaut VARENE
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License version 2.1,
@@ -20,8 +20,8 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 768 $
- * @date 2003-2007
+ * @version $Revision: 780 $
+ * @date 2003-2008
  *
  * That file groups all functions related to HTML and assimilated
  * generation, that is to say functions that are used to
@@ -95,6 +95,7 @@ list_songs(request_rec *r, const mu_ent *const p, const mu_config *const conf,
 	register unsigned short fld = 0, j = 0;
 	const char *current = NULL, *new = NULL;
 	char *codeduri = NULL;
+	unsigned long tlength = 0, tsize = 0;
 
 	ap_rputs("  <tr class=\"title\">\n", r);
 
@@ -278,8 +279,10 @@ list_songs(request_rec *r, const mu_ent *const p, const mu_config *const conf,
 				case SB_LENGTH:
 					if (conf->options & MI_QUICKPL)
 						break;
-					if (q->length)
+					if (q->length) {
 						ap_rprintf(r, "   <td class=\"Length\">%d:%.2d</td>\n", q->length / 60, q->length % 60);
+						tlength += q->length;
+					}
 					else
 						ap_rputs( "   <td></td>\n", r);
 					break;
@@ -319,6 +322,7 @@ list_songs(request_rec *r, const mu_ent *const p, const mu_config *const conf,
 					break;
 				case SB_SIZE:
 					ap_rprintf(r, "   <td class=\"Size\"><acronym title=\"MB\">%ld.%ld</acronym></td>\n", q->size>>20, (q->size>>10)%1024/100);
+					tsize += q->size;
 					break;
 				case SB_FILENAME:
 					ap_rvputs(r, "   <td class=\"Filename\">", ap_escape_html(r->pool, q->filename), "</td>\n", NULL);
@@ -330,7 +334,22 @@ list_songs(request_rec *r, const mu_ent *const p, const mu_config *const conf,
 		/* at the end of the loop, 'fld' contains the number of fields */
 		ap_rputs("  </tr>\n", r);
 	}
+	
 	free(codeduri);
+	
+	/* close the table with some useful stuff */
+	ap_rprintf(r, "  <tr class=\"stfoot\">\n   <th align=\"left\" colspan=\"%d\">", fld+1);	/* Select => +1 */
+	
+	/* Do NOT show 'select all' if there's nothing to select... */
+	if (!customlist && (conf->search) && (conf->options & MI_ALLOWSTREAM))
+		ap_rvputs(r, "<input type=\"checkbox\" name=\"all\" onClick=\"for(var i=0;i<this.form.elements.length;i++){var inpt=this.form.elements[i];"
+			"var m=inpt.name.match(/-/g);if((inpt.name.substr(0,4)=='file') && (m<1)) inpt.checked=this.form.all.checked}\" />",
+			_("Select All"), " - ", NULL);
+	
+	ap_rprintf(r, "%s: %ld:%.2ld:%.2ld - %s: %ld.%ld MB</th>\n  </tr>\n",
+			   _("Total Length"), tlength / 60 / 60, tlength / 60 % 60, tlength % 60,
+			   _("Total Size"), tsize >> 20, (tsize >> 10) % 1024 / 100);
+	
 	return fld;
 }
 
@@ -657,7 +676,7 @@ void send_directories(request_rec *r, const mu_pack *const pack, const mu_config
 			"    <a href=\"", ap_escape_html(r->pool, ap_escape_uri(r->pool, q->file)), "\">",
 			ap_escape_html(r->pool, q->title), "</a>", NULL);
 
-		if (PRETTY_FOLDERS) {
+		if (ENABLE_PRETTY_FOLDERS) {
 			/* show various useful links when needed */
 			ap_rputs("<br />\n", r);
 			if (q->flags & EF_ALLOWSTREAM) {
@@ -736,15 +755,6 @@ void send_tracks(request_rec *r, const mu_pack *const pack, const mu_config *con
 
 	nb = list_songs(r, q, conf, 0);
 
-	/* Do NOT show 'select all' if there's nothing to select... */
-	if ((conf->search) && (conf->options & MI_ALLOWSTREAM)) {
-		ap_rprintf(r, "  <tr class=\"title\"><th align=\"left\" colspan=\"%d\">\n", nb+1); /* Select => +1 */
-		ap_rputs("   <input type=\"checkbox\" name=\"all\" onClick=\"for(var i=0;i<this.form.elements.length;i++){var inpt=this.form.elements[i];"
-			"var m=inpt.name.match(/-/g);if((inpt.name.substr(0,4)=='file') && (m<1)) inpt.checked=this.form.all.checked}\" />\n"
-			"Select All</th>\n"
-			"</tr>\n", r);
-	}
-
 	ap_rputs(" </table>\n", r);
 
 	/* Do NOT show buttons if we do not allow anything but listing or individual downloading! */
@@ -765,6 +775,9 @@ void send_tracks(request_rec *r, const mu_pack *const pack, const mu_config *con
 				_("Shuffle All"), "</button>\n"
 				"  <button type=\"submit\" name=\"action\" value=\"PlayAll\">",
 				_("Play All"), "</button>\n", NULL);
+			if (conf->options & MI_ALLOWTARBALL)
+				ap_rvputs(r, "  <button type=\"submit\" name=\"action\" value=\"DownloadAll\">",
+				_("Download All"), "</button>\n", NULL);
 		}
 
 		if (conf->options & MI_ALLOWSTREAM)
@@ -773,9 +786,7 @@ void send_tracks(request_rec *r, const mu_pack *const pack, const mu_config *con
 
 		if (conf->options & MI_ALLOWTARBALL)
 			ap_rvputs(r, "  <button type=\"submit\" name=\"action\" value=\"DownloadSelected\">",
-				_("Download Selected"), "</button>\n"
-				"  <button type=\"submit\" name=\"action\" value=\"DownloadAll\">",
-				_("Download All"), "</button>\n", NULL);
+				_("Download Selected"), "</button>\n", NULL);
 
 		ap_rputs(" </div>\n", r);
 	}
