@@ -2,11 +2,11 @@
  *  playlist-mp3.c
  *  mod_musicindex
  *
- *  $Id: playlist-mp3.c 753 2007-04-27 14:04:42Z varenet $
+ *  $Id: playlist-mp3.c 778 2008-03-29 20:29:00Z varenet $
  *
  *  Created by Regis BOUDIN on Thu Jan 22 2004.
  *  Copyright (c) 2003-2004 Regis BOUDIN
- *  Copyright (c) 2003-2007 Thibaut VARENE
+ *  Copyright (c) 2003-2008 Thibaut VARENE
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License version 2.1,
@@ -20,8 +20,8 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 753 $
- * @date 2003-2007
+ * @version $Revision: 778 $
+ * @date 2003-2008
  *
  * This file contains everything needed to produce music entries from
  * MP3 files. @n
@@ -209,7 +209,7 @@ static id3_utf8_t *utf8_id3tag_findframe(struct id3_tag *tag, const char *const
 		nstrings = id3_field_getnstrings(field);
 		for (i = 0; i < nstrings; ++i) {
 			if ((ucs4 = id3_field_getstrings(field, i))) {
-				if (strcmp(frameid, ID3_FRAME_GENRE) == 0) {
+				if (frameid == ID3_FRAME_GENRE) {
 					/* Some encoders encaps id nb in brackets and the
 					lib doesn't handle this properly. This is ugly */
 					if ((ucs4[0] == '(') && (isdigit(ucs4[1]))) {
@@ -415,7 +415,10 @@ mu_ent *make_mp3_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
 						p->flags |= EF_VBR;
 					if ((p->flags & EF_VBR))
 						p->bitrate += madheader.bitrate;	/* we'll do an average, XXX overflow when no FAST_CALC? */
-				}
+				}	/* XXX FIXME this loop will yield wrong result eg if the first
+					   2+ frames have the same bitrate, the sum will only trigger
+					   after these and the average performed later on on the total
+					   number of frames will be incorrect. */
 
 				/* We can either scan the whole file to get precise duration & bitrate,
 				or just check a few frames and guess the whole story, if DO_FAST_CALC is set */
@@ -430,7 +433,11 @@ mu_ent *make_mp3_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
 				}
 			}
 			
-			if (madstream.error != MAD_ERROR_BUFLEN)
+			/* We need to break the main loop either on fatal error or, if doing
+			FAST_CALC, when we have already computed the numbers we need. Otherwise
+			things get really messy (frames not being == to the number of frames
+			actually read */
+			if ((madstream.error != MAD_ERROR_BUFLEN) || (DO_FAST_CALC && (frames > MAD_AVERAGE_FRAMES)))
 				break;
 		}
 	
