@@ -2,7 +2,7 @@
  *  playlist.c
  *  mod_musicindex
  *
- *  $Id: playlist.c 769 2007-08-22 12:43:06Z varenet $
+ *  $Id: playlist.c 780 2008-03-30 17:34:13Z varenet $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2004 Regis BOUDIN
@@ -20,7 +20,7 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 769 $
+ * @version $Revision: 780 $
  * @date 2003-2007
  *
  * This is where the magic takes place. Here are the functions in charge of
@@ -340,7 +340,7 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 			*uri++ = '/';
 		*uri = '\0';
 
-		if (PRETTY_FOLDERS) {
+		if (ENABLE_PRETTY_FOLDERS) {
 			subreq = ap_sub_req_lookup_uri(names->uri, r, NULL);
 
 			soptions &= ~(MI_ALLOWFETCH|MI_ALLOWRSS);
@@ -365,7 +365,7 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 			unsigned short	fn_max = MAX_STRING;
 			unsigned short	uri_max = MAX_STRING;
 
-			if (!PRETTY_FOLDERS) {
+			if (!ENABLE_PRETTY_FOLDERS) {
 				subreq = ap_sub_req_lookup_uri(names->uri, r, NULL);
 
 				soptions &= ~(MI_ALLOWFETCH|MI_ALLOWRSS);
